@@ -24,8 +24,10 @@ __all__ = [
     'Freezer',
     'GradientNormClipping',
     'Initializer',
+    'InputShapeSetter',
     'LRScheduler',
     'LoadInitState',
+    'MlflowLogger',
     'NeptuneLogger',
     'ParamMapper',
     'PassthroughScoring',
@@ -33,6 +35,7 @@ __all__ = [
     'ProgressBar',
     'TrainEndCheckpoint',
     'TensorBoard',
+    'SacredLogger',
     'Unfreezer',
     'WandbLogger',
     'WarmRestartLR',
