@@ -440,6 +440,11 @@ class TestDataFromDataset:
         y = np.array([1, 3, 0, 2])
         return X, y
 
+    @pytest.fixture
+    def tensors(self, data):
+        X, y = data
+        return torch.from_numpy(X), torch.from_numpy(y)
+
     @pytest.fixture
     def skorch_ds(self, data):
         from skorch.dataset import Dataset
@@ -501,6 +506,24 @@ class TestDataFromDataset:
         assert (X == data[0][[1, 3]]).all()
         assert y is None
 
+    def test_with_tensordataset_2_vals(self, data_from_dataset, tensors):
+        dataset = torch.utils.data.dataset.TensorDataset(*tensors)
+        X, y = data_from_dataset(dataset)
+        assert (X == tensors[0]).all()
+        assert (y == tensors[1]).all()
+
+    def test_with_tensordataset_1_val_raises(self, data_from_dataset, tensors):
+        dataset = torch.utils.data.dataset.TensorDataset(tensors[0])
+        msg = "Could not access X and y from dataset."
+        with pytest.raises(AttributeError, match=msg):
+            data_from_dataset(dataset)
+
+    def test_with_tensordataset_3_vals_raises(self, data_from_dataset, tensors):
+        dataset = torch.utils.data.dataset.TensorDataset(*tensors, tensors[0])
+        msg = "Could not access X and y from dataset."
+        with pytest.raises(AttributeError, match=msg):
+            data_from_dataset(dataset)
+
 
 class TestMultiIndexing:
     @pytest.fixture
